@@ -69,14 +69,21 @@ class ObjectTypes(Enum):
 
 class ObjectSubTypes(Enum):
     FILTER = 256
+    REPORT_GRID = 768
+    REPORT_GRAPH = 769
+    REPORT_ENGINE = 770
+    REPORT_GRID_AND_GRAPH = 774
     OLAP_CUBE = 776
     INCREMENTAL_REFRESH_REPORT = 777
+    REPORT_TRANSACTION = 778
     SUPER_CUBE = 779
+    REPORT_HYPER_CARD = 781
     FUNCTION = 2816
     USER = 8704
     USER_GROUP = 8705
     SEARCH = 9984
     FUNCTION_PACKAGE_DEFINITION = 10752
+    REPORT_WRITING_DOCUMENT = 14081
     MD_SECURITY_FILTER = 14848
     ATTRIBUTE = 3072
     ATTRIBUTE_ABSTRACT = 3075
