@@ -1,5 +1,5 @@
 from enum import Enum, IntFlag
-from typing import Any, Dict, List, Optional, TYPE_CHECKING, TypeVar, Union
+from typing import Any, Optional, TYPE_CHECKING, TypeVar
 
 import pandas as pd
 
@@ -74,7 +74,7 @@ class ACE(Dictable):
         self,
         deny: bool,
         entry_type: int,
-        rights: Union[Rights, int],
+        rights: Rights | int,
         trustee_id: str,
         trustee_name: str,
         trustee_type: int,
@@ -95,9 +95,15 @@ class ACE(Dictable):
             inheritable: Specifies whether access control is inherited
         """
 
+        self.rights = rights if isinstance(rights, Rights) else Rights(rights)
+        if self.rights not in range(256) and self.rights not in range(536_870_912, 536_871_167):
+            msg = (
+                "Wrong `rights` value, please provide value in range 0-255 or combination of "
+                "Rights enums"
+            )
+            exception_handler(msg)
         self.deny = deny
         self.entry_type = entry_type
-        self.rights = rights if isinstance(rights, Rights) else Rights(rights)
         self.trustee_id = trustee_id
         self.trustee_name = trustee_name
         self.trustee_type = trustee_type
@@ -113,7 +119,7 @@ class ACE(Dictable):
         return True
 
     @classmethod
-    def from_dict(cls, source: Dict[str, Any], connection: Connection):
+    def from_dict(cls, source: dict[str, Any], connection: Connection):
 
         def translate_names(name: str):
             if name == "type":
@@ -133,6 +139,17 @@ class ACE(Dictable):
         result_dict = super().to_dict(camel_case=camel_case)
         return {translate_names(key): val for key, val in result_dict.items()}
 
+    def _get_request_body(self, op):
+        result_dict = {
+            "op": op,
+            "trustee": self.trustee_id,
+            "rights": self.rights.value,
+            "type": self.entry_type,
+            "denied": self.deny,
+            "inheritable": self.inheritable
+        }
+        return result_dict
+
 
 class ACLMixin:
     """ACLMixin class adds Access Control List (ACL) management for supporting
@@ -148,13 +165,15 @@ class ACLMixin:
     NOTE: Must be mixedin with Entity or its subclasses.
     """
 
-    def list_acl(self, to_dataframe: bool = False, **filters) -> Union[pd.DataFrame, list]:
+    def list_acl(self, to_dataframe: bool = False, to_dictionary: bool = False,
+                 **filters) -> pd.DataFrame | list[dict | ACE]:
         """Get Access Control List (ACL) for this object. Optionally filter
         ACLs by specifying filters.
 
         Args:
             to_dataframe(bool, optional): if True, return datasets as
                 pandas DataFrame
+            to_dictionary(bool, optional): if True, return datasets as dicts
             **filters: Available filter parameters: [deny, type, rights,
                 trustee_id, trustee_name, trustee_type, trustee_subtype,
                 inheritable]
@@ -165,15 +184,17 @@ class ACLMixin:
         acl = filter_obj_list(self.acl, **filters)
         if to_dataframe:
             return pd.DataFrame(acl)
+        elif to_dictionary:
+            return [acl_obj.to_dict() for acl_obj in acl]
         else:
             return acl
 
     def acl_add(
         self: "Entity",
-        rights: Union[int, Rights, AggregatedRights],
-        trustees: Union["UserOrGroup", List["UserOrGroup"]],
+        rights: int | Rights | AggregatedRights,
+        trustees: "list[UserOrGroup] | UserOrGroup",
         denied: bool = False,
-        inheritable: bool = False,
+        inheritable: Optional[bool] = None,
         propagate_to_children: Optional[bool] = None
     ) -> None:
         """Add Access Control Element (ACE) to the object ACL.
@@ -210,10 +231,10 @@ class ACLMixin:
 
     def acl_remove(
         self: "Entity",
-        rights: Union[int, Rights, AggregatedRights],
-        trustees: Union["UserOrGroup", List["UserOrGroup"]],
+        rights: int | Rights | AggregatedRights,
+        trustees: "list[UserOrGroup] | UserOrGroup",
         denied: bool = False,
-        inheritable: bool = False,
+        inheritable: Optional[bool] = None,
         propagate_to_children: Optional[bool] = None
     ) -> None:
         """Remove Access Control Element (ACE) from the object ACL.
@@ -250,10 +271,10 @@ class ACLMixin:
 
     def acl_alter(
         self: "Entity",
-        rights: Union[int, Rights, AggregatedRights],
-        trustees: Union["UserOrGroup", List["UserOrGroup"]],
+        rights: int | Rights | AggregatedRights,
+        trustees: "list[UserOrGroup] | UserOrGroup",
         denied: bool = False,
-        inheritable: bool = False,
+        inheritable: Optional[bool] = None,
         propagate_to_children: Optional[bool] = None
     ) -> None:
         """Alter an existing Access Control Element (ACE) of the object ACL.
@@ -291,11 +312,11 @@ class ACLMixin:
     def _update_acl(
         self: "Entity",
         op: str,
-        rights: Union[int, Rights, AggregatedRights],
-        trustees: Union["UserOrGroup", List["UserOrGroup"]],
-        propagate_to_children: Optional[bool] = None,
+        rights: int | Rights | AggregatedRights,
+        trustees: "list[UserOrGroup] | UserOrGroup",
         denied: bool = False,
-        inheritable: bool = False
+        inheritable: Optional[bool] = None,
+        propagate_to_children: Optional[bool] = None,
     ) -> None:
         """Updates the ACL for this object, performs operation defined by the
         `op` parameter on all objects from `trustees` list.
@@ -309,54 +330,27 @@ class ACLMixin:
                 "REPLACE"
             rights: value of rights to use by the operator
             trustees: list of trustees to update the ACE for
-            propagate_to_children: used for folder objects only, default value
-                is None, if set to True/False adds `propagateACLToChildren`
-                keyword to the request body and sets its value accordingly
             denied: flag to indicate granted or denied access to the object
             inheritable: Applies only to folders. If set, any objects placed in
                 the folder inherit the folder's entry in the ACL.
+            propagate_to_children: used for folder objects only, default value
+                is None, if set to True/False adds `propagateACLToChildren`
+                keyword to the request body and sets its value accordingly
         """
-        # TODO merge duplicated code with _modify_rights function
-        # TODO move (op, rights, ids, propagate_to_children=None,
-        # denied=None, inheritable=None, types=None) to
-        # separate AccesControlEntry class
-        if op not in ["ADD", "REMOVE", "REPLACE"]:
-            raise ValueError("Wrong ACL operator passed. Please use ADD, REMOVE or REPLACE")
 
-        # convert Enums
-        rights = rights.value if isinstance(rights, Enum) else rights
-        if rights not in range(256) and rights not in range(536_870_912, 536_871_167):
-            msg = (
-                "Wrong `rights` value, please provide value in range 0-255 or combination of "
-                "Rights enums"
-            )
-            raise ValueError(msg)
-        if not isinstance(trustees, list):
-            trustees = [trustees]
-        trustee_ids = [trustee if isinstance(trustee, str) else trustee.id for trustee in trustees]
-        body = {
-            "acl": [
-                {
-                    "op": op,
-                    "trustee": id,
-                    "rights": rights,
-                    "type": 1,  # EnumDSSXMLAccessEntryType
-                    "denied": denied,
-                    "inheritable": inheritable
-                } for id in trustee_ids
-            ]
-        }
-
-        if isinstance(propagate_to_children, bool) and self._OBJECT_TYPE is ObjectTypes.FOLDER:
-            body["propagateACLToChildren"] = propagate_to_children
-            body["propagationBehavior"] = "overwrite_recursive"
-
-        response = objects.update_object(
-            connection=self.connection, id=self.id, body=body, object_type=self._OBJECT_TYPE.value
+        response = modify_rights(
+            connection=self.connection,
+            object_type=self._OBJECT_TYPE,
+            ids=self.id,
+            op=op,
+            rights=rights,
+            trustees=trustees,
+            denied=denied,
+            inheritable=inheritable,
+            propagate_to_children=propagate_to_children
         )
-        if response.ok:
-            response = response.json()
-            self._set_object_attributes(**response)
+
+        self._set_object_attributes(**response)
 
 
 class TrusteeACLMixin:
@@ -367,10 +361,10 @@ class TrusteeACLMixin:
 
     def set_permission(
         self,
-        permission: Union[Permissions, str],
-        to_objects: Union[str, List[str]],
-        object_type: "ObjectTypes",
-        project: Optional[Union[str, "Project"]] = None,
+        permission: Permissions | str,
+        to_objects: str | list[str],
+        object_type: "ObjectTypes | int",
+        project: "Optional[Project | str]" = None,
         propagate_to_children: Optional[bool] = None
     ) -> None:
         """Set permission to perform actions on given object(s).
@@ -413,54 +407,52 @@ class TrusteeACLMixin:
 
         # those 2 tries are for clearing current rights (set to default values)
         try:
-            _modify_rights(
+            modify_rights(
                 connection=self.connection,
-                trustee_id=self.id,
+                object_type=object_type,
+                trustees=self.id,
                 op='REMOVE',
                 rights=AggregatedRights.ALL.value,
                 ids=to_objects,
-                object_type=object_type,
-                project=project,
                 denied=(not denied),
                 propagate_to_children=propagate_to_children,
-                verbose=False
+                project=project
             )
         except IServerError:
             pass
         try:
-            _modify_rights(
+            modify_rights(
                 connection=self.connection,
-                trustee_id=self.id,
+                object_type=object_type,
+                trustees=self.id,
                 op='REMOVE',
                 rights=AggregatedRights.ALL.value,
                 ids=to_objects,
-                object_type=object_type,
-                project=project,
                 denied=denied,
                 propagate_to_children=propagate_to_children,
-                verbose=False
+                project=project
             )
         except IServerError:
             pass
 
         if permission != Permissions.DEFAULT_ALL:
-            _modify_rights(
+            modify_rights(
                 connection=self.connection,
-                trustee_id=self.id,
+                object_type=object_type,
+                trustees=self.id,
                 op='ADD',
                 rights=right_value,
                 ids=to_objects,
-                object_type=object_type,
-                project=project,
                 denied=denied,
-                propagate_to_children=propagate_to_children
+                propagate_to_children=propagate_to_children,
+                project=project
             )
 
     def set_custom_permissions(
         self,
-        to_objects: Union[str, List[str]],
-        object_type: Union["ObjectTypes", int],
-        project: Optional[Union[str, "Project"]] = None,
+        to_objects: str | list[str],
+        object_type: "ObjectTypes | int",
+        project: "Optional[Project | str]" = None,
         execute: Optional[str] = None,
         use: Optional[str] = None,
         control: Optional[str] = None,
@@ -483,7 +475,7 @@ class TrusteeACLMixin:
         Args:
             to_objects: (str, list(str)): List of object ids on access list to
                 which the permissions will be set
-            object_type (int): Type of objects on access list
+            object_type (int, ObjectTypes): Type of objects on access list
             project (str, Project): Object or id of Project in which
                 the object is located. If not passed, Project
                 (project_id) selected in Connection object is used.
@@ -508,46 +500,43 @@ class TrusteeACLMixin:
         def modify_custom_rights(
             connection,
             trustee_id: str,
-            right: Union[Rights, List[Rights]],
-            to_objects: List[str],
-            object_type: "ObjectTypes",
+            right: Rights | list[Rights],
+            to_objects: list[str],
+            object_type: "ObjectTypes | int",
             denied: bool,
-            project: Optional[Union[str, "Project"]] = None,
             default: bool = False,
-            propagate_to_children: Optional[bool] = None
+            propagate_to_children: Optional[bool] = None,
+            project: "Optional[Project | str]" = None
         ) -> None:
 
             right_value = _get_custom_right_value(right)
             try:
-                _modify_rights(
+                modify_rights(
                     connection=connection,
-                    trustee_id=trustee_id,
+                    trustees=trustee_id,
                     op='REMOVE',
                     rights=right_value,
                     ids=to_objects,
                     object_type=object_type,
                     project=project,
                     denied=(not denied),
-                    propagate_to_children=propagate_to_children,
-                    verbose=False
+                    propagate_to_children=propagate_to_children
                 )
             except IServerError:
                 pass
 
             op = 'REMOVE' if default else 'ADD'
-            verbose = not default
             try:
-                _modify_rights(
+                modify_rights(
                     connection=connection,
-                    trustee_id=trustee_id,
+                    trustees=trustee_id,
                     op=op,
                     rights=right_value,
                     ids=to_objects,
                     object_type=object_type,
                     project=project,
                     denied=denied,
-                    propagate_to_children=propagate_to_children,
-                    verbose=verbose
+                    propagate_to_children=propagate_to_children
                 )
             except IServerError:
                 pass
@@ -602,81 +591,117 @@ class TrusteeACLMixin:
         )
 
 
-def _modify_rights(
+def modify_rights(
     connection,
-    trustee_id: str,
+    object_type: "ObjectTypes | int",
+    ids: list[str] | str,
     op: str,
     rights: int,
-    object_type: "ObjectTypes",
-    ids: List[str],
-    project: Optional[Union[str, "Project"]] = None,
-    propagate_to_children: Optional[bool] = None,
-    denied: Optional[bool] = None,
+    trustees: "list[UserOrGroup] | UserOrGroup",
+    denied: bool = False,
     inheritable: Optional[bool] = None,
-    verbose: bool = True
-) -> None:
+    propagate_to_children: Optional[bool] = None,
+    project: "Optional[Project | str]" = None,
+) -> None | dict:
+    """Updates the ACL for all given objects specified by id from ids list,
+    performs operation defined by the `op` parameter on all objects for
+    every user or group from `trustees` list.
+
+    Note:
+        Argument `inheritable` and `propagate_to_children` are used only
+        for objects with type `ObjectTypes.FOLDER`.
+
+    Args:
+        object_type (ObjectTypes, int): Type of every object from ids list.
+            One of EnumDSSXMLObjectTypes. Ex. 34 (User or UserGroup),
+            44 (Security Role), 32 (Project), 8 (Folder).
+        ids (list[str], str): List of object ids or one object id on which
+            operations will be performed.
+        op (str): ACL update operator, available values are "ADD", "REMOVE"
+            and "REPLACE".
+        rights (int): Value of rights to use by the operator.
+        trustees (list[UserOrGroup], UserOrGroup): List of trustees or one
+            trustee to update the ACE for.
+        denied (bool): Flag to indicate granted or denied access
+            to the object.
+        inheritable (bool, optional): Applies only to folders. If set, any
+            objects placed in the folder inherit the folder's entry
+            in the ACL.
+        propagate_to_children (bool, optional): Used for folder objects
+            only, default value is None, if set to True/False adds
+            `propagateACLToChildren` keyword to the request body and sets
+            its value accordingly.
+        project (Project, str, optional): Project object or project id
+            on which objects are stored, if not specified project id from
+            connection will be used.
+
+    Returns:
+        Dict with updated object properties if there was only one id in ids
+        list or None.
+    """
+    if not isinstance(ids, list):
+        ids = [ids]
+    if not isinstance(trustees, list):
+        trustees = [trustees]
+    if not isinstance(object_type, ObjectTypes):
+        object_type = ObjectTypes(object_type)
+
+    trustees = [trustee if isinstance(trustee, str) else trustee.id for trustee in trustees]
+    project = project.id if project and not isinstance(project, str) else project
     if op not in ["ADD", "REMOVE", "REPLACE"]:
         raise ValueError("Wrong ACL operator passed. Please use ADD, REMOVE or REPLACE")
 
-    # convert Enums
-    rights = rights.value if isinstance(rights, Enum) else rights
-    if rights not in range(256) and rights not in range(536_870_912, 536_871_168):
-        msg = (
-            "Wrong `rights` value, please provide value in range 0-255 or combination of "
-            "Rights enums"
-        )
-        exception_handler(msg)
-
-    if project:
-        project = project if isinstance(project, str) else project.id
-
-    if isinstance(ids, str):
-        ids = [ids]
-
     for id in ids:
-        response = objects.get_object_info(
-            connection=connection, id=id, object_type=object_type.value, project_id=project
-        )
-        if inheritable is None:
-            tmp = [
-                ace['inheritable']
-                for ace in response.json().get('acl', [])
-                if ace['trusteeId'] == trustee_id and ace['deny'] == denied
-            ]
-            inheritable = False if not tmp else tmp[0]
+        for trustee in trustees:
+            if inheritable is None and object_type is ObjectTypes.FOLDER:
+                response = objects.get_object_info(
+                    connection=connection,
+                    id=id,
+                    object_type=object_type.value,
+                    project_id=project
+                ).json()
+                tmp = [
+                    ace['inheritable']
+                    for ace in response.get('acl', [])
+                    if ace['trusteeId'] == trustee and ace['deny'] == denied
+                ]
+                inheritable = False if not tmp else tmp[0]
 
-        body = {
-            "acl": [
-                {
-                    "op": op,
-                    "trustee": trustee_id,
-                    "rights": rights,
-                    "type": 1,  # EnumDSSXMLAccessEntryType
-                    "denied": denied,
-                    "inheritable": inheritable
-                }
-            ]
-        }
+            body = {
+                "acl": [
+                    ACE(
+                        rights=rights,
+                        trustee_id=trustee,
+                        deny=denied,
+                        inheritable=inheritable,
+                        trustee_name=None,
+                        trustee_type=None,
+                        trustee_subtype=None,
+                        entry_type=1
+                    )._get_request_body(op=op)
+                ]
+            }
 
-        if isinstance(propagate_to_children, bool):
-            body["propagateACLToChildren"] = propagate_to_children
-            body["propagationBehavior"] = "overwrite_recursive"
+            if propagate_to_children and object_type is ObjectTypes.FOLDER:
+                body["propagateACLToChildren"] = propagate_to_children
+                body["propagationBehavior"] = "overwrite_recursive"
 
-        _ = objects.update_object(
-            connection=connection,
-            id=id,
-            body=body,
-            object_type=object_type.value,
-            project_id=project,
-            verbose=verbose
-        )
+            response = objects.update_object(
+                connection=connection,
+                id=id,
+                body=body,
+                object_type=object_type.value,
+                project_id=project
+            )
+        if len(ids) == 1 and response.ok:
+            return response.json()
 
 
-def _parse_acl_rights_bin_to_dict(rights_bin: int) -> Dict[Rights, bool]:
+def _parse_acl_rights_bin_to_dict(rights_bin: int) -> dict[Rights, bool]:
     return {right: rights_bin & right.value != 0 for right in Rights}
 
 
-def _parse_acl_rights_dict_to_bin(rights_dict: Dict[Rights, bool]) -> int:
+def _parse_acl_rights_dict_to_bin(rights_dict: dict[Rights, bool]) -> int:
     output = 0
     for right, given in rights_dict.items():
         if given:
@@ -684,7 +709,7 @@ def _parse_acl_rights_dict_to_bin(rights_dict: Dict[Rights, bool]) -> int:
     return output
 
 
-def _get_custom_right_value(right: Union[Rights, List[Rights]]) -> int:
+def _get_custom_right_value(right: Rights | list[Rights]) -> int:
     right_value = 0
     if not isinstance(right, list):
         right = [right]
