@@ -14,6 +14,7 @@ class SettingValueFactory():
             'time': TimeSetting,
             'email': EmailSetting,
             'object': ObjectSetting,
+            'mstr_object': MstrObjectSetting,
             None: DeprecatedSetting
         }
         setting_type = config.get('type')
@@ -182,6 +183,15 @@ class ObjectSetting(SettingValue):
         self.object_type = config.get('object_type')
 
 
+class MstrObjectSetting(SettingValue):
+    """Representation of an MstrObject setting type."""
+
+    def __init__(self, config: dict):
+        super().__init__(config)
+        self.type = str
+        self.object_type = config.get('object_type')
+
+
 class DeprecatedSetting:
     """Representation of a Deprecated setting type."""
 
